/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WCACHE_H
#define WCACHE_H

#include "tbox.h"
#include "wGauss.h"
#include <vector>
#include <Eigen/Dense>

namespace tbox
{

/**
 * @brief Base cache for element
 * @authors Romain Boman, Adrien Crovato
 */
class TBOX_API Cache
{
protected:
    int n;                            ///< degree of element
    std::vector<Eigen::MatrixXd> dff; ///< derivative of shape functions
    std::vector<Eigen::VectorXd> ff;  ///< shape functions

public:
    explicit Cache(int _n);
    virtual ~Cache() {}

    inline Eigen::MatrixXd const &getDsf(size_t k);
    inline Eigen::VectorXd const &getSf(size_t k);
    virtual Gauss &getVGauss();
};

#include "wCache.inl"

} // namespace tbox

#endif // WCACHE_H
