/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WRESULTS_H
#define WRESULTS_H

#include "tbox.h"
#include "wObject.h"
#include <string>
#include <vector>
#include <map>
#include <Eigen/Dense>

namespace tbox
{

/**
 * @brief Results data structure
 * @authors Romain Boman
 */
class TBOX_API Results : public fwk::wObject
{
public:
#ifndef SWIG
    int nt;
    double time;
    std::map<std::string, std::vector<double> *> scalars_at_nodes;
    std::map<std::string, std::vector<double> *> scalars_at_slave_nodes;
    std::map<std::string, std::vector<double> *> scalars_at_elems;
    std::map<std::string, std::vector<Eigen::Vector3d> *> vectors_at_nodes;
    std::map<std::string, std::vector<Eigen::Vector3d> *> vectors_at_elems;
    std::map<std::string, std::vector<Eigen::MatrixXd> *> tensors_at_nodes;
    std::map<std::string, std::vector<Eigen::MatrixXd> *> tensors_at_elems;
#endif

    Results();

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace tbox

#endif // WRESULTS_H
